<?php
error_reporting(E_ALL);

// Example code that allows downloading of files from GameMaster.
// Requires a version of GameMaster that supports file downloads (at least 0.9).
// Copyright Martin Persson System & Design 2009
// View this file with tabstop=4, shiftwidth=4, or face the consequences.
// And if you use spaces for indentation, then you are simply WRONG.

print "Starting script...\n";

if ($argc < 2) {
	die("Usage: get.php <remote-path>\n");
}

$output_filename = basename($argv[1]);

if (file_exists($output_filename)) {
	die("A local file with the name \"$output_filename\" already exists.\n");
}

$command = array('command' => 'get',
		'path' => $argv[1],
		'username' => 'localadmin',
		'password' => 'secret');

$address = '127.0.0.1';
$port = 4554;

# We need to append a newline at the end to indicate to the Perl-based
# server that the input is ending.
$json_command = json_encode($command) . "\n";

print "Creating socket...\n";
if (($socket = socket_create(AF_INET, SOCK_STREAM,
		getprotobyname('tcp'))) === FALSE) {
	die("Unable to create TCP socket.\n");
}

print "Connecting to remote host $address on port $port...\n";
if (!socket_connect($socket, $address, $port)) {
	die("Unable to connect to remote host.\n");
}

print "Writing command to socket...\n";
if (($bytes_written = socket_write($socket, $json_command)) === FALSE) {
	die("Unable to write JSON encoded data to socket.\n");
}

print "Reading response from socket...\n";
if (($response_json = socket_read($socket, 2048, PHP_NORMAL_READ)) === FALSE) {
	die("Unable to read server response from socket.\n");
}
print "Closing socket...\n";
socket_close($socket);

# Remove trailing extra newline.
$response_json = chop($response_json);

$response = json_decode($response_json, true);

if ($response['status'] == 'error') {
	print "An error occured: \"" . $response['message'] . "\n";
} else {
	$data = base64_decode($response['contents']);

	print "Creating local file.\n";
	if (($handle = fopen($output_filename, "w")) === FALSE) {
		die("Unable to open local file for writing.\n");
	}

	fwrite($handle, $data);
	fclose($handle);
}

?>

